==> mysql-connector-net-8.0.22-src.zip: EFCore/src/Metadata/Internal/MySQLAnnotationNames.cs <==
// Copyright (c) 2015, 2020 Oracle and/or its affiliates.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License, version 2.0, as
// published by the Free Software Foundation.
//
// This program is also distributed with certain software (including
// but not limited to OpenSSL) that is licensed under separate terms,
// as designated in a particular file or component or in included license
// documentation.  The authors of MySQL hereby grant you an
// additional permission to link the program and your derivative works
// with the separately licensed software that they have included with
// MySQL.
//
// Without limiting anything contained in the foregoing, this file,
// which is part of MySQL Connector/NET, is also subject to the
// Universal FOSS Exception, version 1.0, a copy of which can be found at
// http://oss.oracle.com/licenses/universal-foss-exception.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU General Public License, version 2.0, for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation, Inc.,
// 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA

namespace MySql.Data.EntityFrameworkCore.Metadata.Internal
{
  /// <summary>
  /// Names for MySQL annotations.
  /// </summary>
  internal static class MySQLAnnotationNames
  {
    public const string Prefix = "MySQL:";

    /// <summary>
    ///     This API supports the Entity Framework Core infrastructure and is not intended to be used
    ///     directly from your code. This API may change or be removed in future releases.
    /// </summary>
    public const string ValueGenerationStrategy = Prefix + "ValueGenerationStrategy";
    public const string LegacyValueGeneratedOnAddOrUpdate = Prefix + "ValueGeneratedOnAddOrUpdate";
    public const string LegacyValueGeneratedOnAdd = Prefix + "ValueGeneratedOnAdd";
    public const string FullTextIndex = Prefix + "FullTextIndex";
    public const string SpatialIndex = Prefix + "SpatialIndex";
    public const string DefaultValueSql = Prefix + "DefaultValueSql";
    public const string Charset = Prefix + "Charset";
    public const string Collation = Prefix + "Collation";
  }
}

==> mysql-connector-net-8.0.28-src.zip: EFCore/src/Metadata/Internal/MySQLAnnotationNames.cs <==
// Copyright (c) 2015, 2020 Oracle and/or its affiliates.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License, version 2.0, as
// published by the Free Software Foundation.
//
// This program is also distributed with certain software (including
// but not limited to OpenSSL) that is licensed under separate terms,
// as designated in a particular file or component or in included license
// documentation.  The authors of MySQL hereby grant you an
// additional permission to link the program and your derivative works
// with the separately licensed software that they have included with
// MySQL.
//
// Without limiting anything contained in the foregoing, this file,
// which is part of MySQL Connector/NET, is also subject to the
// Universal FOSS Exception, version 1.0, a copy of which can be found at
// http://oss.oracle.com/licenses/universal-foss-exception.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
// See the GNU General Public License, version 2.0, for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software Foundation, Inc.,
// 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA

namespace MySql.EntityFrameworkCore.Metadata.Internal
{
  /// <summary>
  /// Names for MySQL annotations.
  /// </summary>
  internal static class MySQLAnnotationNames
  {
    public const string Prefix = "MySQL:";

    /// <summary>
    ///     This API supports the Entity Framework Core infrastructure and is not intended to be used
    ///     directly from your code. This API may change or be removed in future releases.
    /// </summary>
    public const string ValueGenerationStrategy = Prefix + "ValueGenerationStrategy";
    public const string LegacyValueGeneratedOnAddOrUpdate = Prefix + "ValueGeneratedOnAddOrUpdate";
    public const string LegacyValueGeneratedOnAdd = Prefix + "ValueGeneratedOnAdd";
    public const string FullTextIndex = Prefix + "FullTextIndex";
    public const string SpatialIndex = Prefix + "SpatialIndex";
    public const string DefaultValueSql = Prefix + "DefaultValueSql";
    public const string Charset = Prefix + "Charset";
    public const string Collation = Prefix + "Collation";
  }
}
